==> huaweicloudsdkcodecheck-3.0.69-py2.py3-none-any.whl: huaweicloudsdkcodecheck/v2/model/list_rulesets_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListRulesetsRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'category': 'str',
        'offset': 'int',
        'limit': 'int'
    }

    attribute_map = {
        'project_id': 'project_id',
        'category': 'category',
        'offset': 'offset',
        'limit': 'limit'
    }

    def __init__(self, project_id=None, category=None, offset=None, limit=None):
        """ListRulesetsRequest - a model defined in huaweicloud sdk"""
        
        

        self._project_id = None
        self._category = None
        self._offset = None
        self._limit = None
        self.discriminator = None

        self.project_id = project_id
        if category is not None:
            self.category = category
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit

    @property
    def project_id(self):
        """Gets the project_id of this ListRulesetsRequest.

        项目ID

        :return: The project_id of this ListRulesetsRequest.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ListRulesetsRequest.

        项目ID

        :param project_id: The project_id of this ListRulesetsRequest.
        :type: str
        """
        self._project_id = project_id

    @property
    def category(self):
        """Gets the category of this ListRulesetsRequest.

        规则集类别  '0只查询系统规则集，1只查询当前用户自定义规则集，2只查询其他用户自定义规则集，'0,1,2'或''查所有'

        :return: The category of this ListRulesetsRequest.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ListRulesetsRequest.

        规则集类别  '0只查询系统规则集，1只查询当前用户自定义规则集，2只查询其他用户自定义规则集，'0,1,2'或''查所有'

        :param category: The category of this ListRulesetsRequest.
        :type: str
        """
        self._category = category

    @property
    def offset(self):
        """Gets the offset of this ListRulesetsRequest.

        分页索引，偏移量

        :return: The offset of this ListRulesetsRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListRulesetsRequest.

        分页索引，偏移量

        :param offset: The offset of this ListRulesetsRequest.
        :type: int
        """
        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this ListRulesetsRequest.

        每页显示的数量

        :return: The limit of this ListRulesetsRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListRulesetsRequest.

        每页显示的数量

        :param limit: The limit of this ListRulesetsRequest.
        :type: int
        """
        self._limit = limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListRulesetsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodecheck-3.1.4-py2.py3-none-any.whl: huaweicloudsdkcodecheck/v2/model/list_rulesets_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListRulesetsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'category': 'str',
        'offset': 'int',
        'limit': 'int'
    }

    attribute_map = {
        'project_id': 'project_id',
        'category': 'category',
        'offset': 'offset',
        'limit': 'limit'
    }

    def __init__(self, project_id=None, category=None, offset=None, limit=None):
        """ListRulesetsRequest

        The model defined in huaweicloud sdk

        :param project_id: 项目ID
        :type project_id: str
        :param category: 规则集类别  &#39;0只查询系统规则集，1只查询当前用户自定义规则集，2只查询其他用户自定义规则集，&#39;0,1,2&#39;或&#39;&#39;查所有&#39;
        :type category: str
        :param offset: 分页索引，偏移量
        :type offset: int
        :param limit: 每页显示的数量
        :type limit: int
        """
        
        

        self._project_id = None
        self._category = None
        self._offset = None
        self._limit = None
        self.discriminator = None

        self.project_id = project_id
        if category is not None:
            self.category = category
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit

    @property
    def project_id(self):
        """Gets the project_id of this ListRulesetsRequest.

        项目ID

        :return: The project_id of this ListRulesetsRequest.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ListRulesetsRequest.

        项目ID

        :param project_id: The project_id of this ListRulesetsRequest.
        :type project_id: str
        """
        self._project_id = project_id

    @property
    def category(self):
        """Gets the category of this ListRulesetsRequest.

        规则集类别  '0只查询系统规则集，1只查询当前用户自定义规则集，2只查询其他用户自定义规则集，'0,1,2'或''查所有'

        :return: The category of this ListRulesetsRequest.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ListRulesetsRequest.

        规则集类别  '0只查询系统规则集，1只查询当前用户自定义规则集，2只查询其他用户自定义规则集，'0,1,2'或''查所有'

        :param category: The category of this ListRulesetsRequest.
        :type category: str
        """
        self._category = category

    @property
    def offset(self):
        """Gets the offset of this ListRulesetsRequest.

        分页索引，偏移量

        :return: The offset of this ListRulesetsRequest.
        :rtype: int
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListRulesetsRequest.

        分页索引，偏移量

        :param offset: The offset of this ListRulesetsRequest.
        :type offset: int
        """
        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this ListRulesetsRequest.

        每页显示的数量

        :return: The limit of this ListRulesetsRequest.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListRulesetsRequest.

        每页显示的数量

        :param limit: The limit of this ListRulesetsRequest.
        :type limit: int
        """
        self._limit = limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListRulesetsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
